@@ -1,11 +1,11 @@
-use generic_vec::{InitSliceVec, SliceVec};
+use cl_generic_vec::SliceVec;
 
 #[test]
 fn split_off() {
     let output = mockalloc::record_allocs(|| {
         new_vec!(mut vec, max(8));
         vec.extend(0..8);
-        let mut other = generic_vec::uninit_array!(4);
+        let mut other = cl_generic_vec::uninit_array::<_, 4>();
         let mut other = SliceVec::new(&mut other);
         vec.split_off_into(4, &mut other);
         assert_eq!(vec, [0, 1, 2, 3]);
@@ -15,20 +15,6 @@ fn split_off() {
     assert_eq!(output.mem_allocated(), output.mem_freed() + leak!(simple));
 }
 
-#[test]
-fn consume_extend() {
-    let output = mockalloc::record_allocs(|| {
-        new_vec!(mut vec, max(4));
-        let mut other = [0, 1, 2, 3];
-        let mut other = InitSliceVec::new(&mut other);
-        other.split_off_into(0, &mut vec);
-        assert_eq!(vec, [0, 1, 2, 3]);
-        assert_eq!(other, []);
-    });
-
-    assert_eq!(output.mem_allocated(), output.mem_freed() + leak!(simple));
-}
-
 #[test]
 fn grow() {
     let output = mockalloc::record_allocs(|| {
